# Mercury SDK
The mercury sdk contains a python library used for interacting with
the Mercury HTTP API service as well as the Mercury CLI, `mcli`. 


## Installation
    # pip install mercury-sdk==0.0.13.dev0